@@ -174,6 +174,7 @@ my %old_license_table_2 = (
     'hubner'        => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'huerlimann'    => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'huftis'        => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
+    'ibragimov'     => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'ilic'          => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'ikomissarov'   => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
     'ivan'          => ['gplv23', 'lgplv23', 'gplv2+', 'lgplv2+', '+eV' ],
@@ -413,6 +414,7 @@ my %secondary_mail_addresses = (
     'asmond@gmx.com' => 'asensi',
     'athurh@gmail.com' => 'athurhfree',
     'bero@arklinux.org' => 'bero',
+    'bhush94@gmail.com' => 'bshah',
     'caleb@gentoo.org' => 'ctennis',
     'christoph@maxiom.de' => 'cfeck',
     'devel@the-user.org' => 'schmidt-domine',
